A simple package to parse the WDS catalog into an astropy table.

Retrieve the `wdsweb_summ2.txt` file from the  https://crf.usno.navy.mil/wdstext website.

Call `wds_astropy_table.parse_wdsweb(filename)` with the path to said file. An astropy table will be returned.